API docs for “spamfighter.core.firewall.SkipFirewallStatement”

# Class s.c.f.SkipFirewallStatement(FirewallStatement):

Part of spamfighter.core.firewall View Source View In Hierarchy

Реализация правила 'skip to ...'.

Instance Variables | skip_label | лейбл, до которого пропускать правила (type: `int` )

Method | __init__ | Конструктор.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented
Method | __str__ | Получить строковое представление правила (в исходной грамматике).
Method | compile | Скомпилировать правило, присоединив его к цепочке deferred.
Method | _skipto_helper | Callback, который обеспечивает выполнение skip to (если if-часть позволяет это).

Inherited from FirewallStatement:

Method | _if_helper | Элемент цепочки отложенных вызовов, отвечающий за обработку условия.
Method | _label_helper | Errback, который ловит `SkipToProcess`, чтобы обеcпечить остановку

def __init__(self, skip_label, **kwargs): (source)
overrides spamfighter.core.firewall.FirewallStatement.__init__
Конструктор.

def __eq__(self, other): (source)
overrides spamfighter.core.firewall.FirewallStatement.__eq__
Undocumented
def __repr__(self): (source)
overrides spamfighter.core.firewall.FirewallStatement.__repr__
Undocumented
def __str__(self): (source)
overrides spamfighter.core.firewall.FirewallStatement.__str__
Получить строковое представление правила (в исходной грамматике).

Returns | (type: `str` )

def compile(self, d, debug=False): (source)
overrides spamfighter.core.firewall.FirewallStatement.compile
Скомпилировать правило, присоединив его к цепочке deferred.

Parameters | d | цепочка отложенных вызовов (type: `twisted.internet.defer.Deferred` )
| debug | включить отладочный режим? (type: `bool` )

def _skipto_helper(self, pack, debug=False): (source)
Callback, который обеспечивает выполнение skip to (если if-часть позволяет это).

Parameters | pack | информация о обрабатываемом сообщении (type: `FirewallMessagePack` )
| debug | включить отладочный режим? (type: `bool` )